<?php

/**
 * Plugin Name: Anycover
 * Plugin URI: app.anycover.co
 * Description: Anycover
 * Version: 1.0.0
 * Author: Anycover
 * Author URI: anycover.co
 * License GNU AGPLv3
 * Requires PHP: 7.4
 * 
 * @category Extended_Insurance_Services
 * @package  Anycover
 * @author   Anycover <hello@anycover.co>
 * @license  GNU AGPLv3
 * @link     anycover.co
 * @since    7.4
 */
defined('ABSPATH') || exit('No direct script access allowed');

// Added support for duplicate sku's.
add_filter('wc_product_has_unique_sku', '__return_false');

$CONFIG = [

    'API_URL' => 'https://api.anycover.co/api',
    'UI_URL' => 'https://merchant.anycover.co',
    'WIDGET_URL' => 'https://widget.anycover.co/widget.js'
];

/**
 * Plugin activation callback. Registers option to redirect on next admin load.
 *
 * Saves user ID to ensure it only redirects for the user who activated the plugin.
 *
 * Redirects the user after plugin activation.
 */
register_activation_hook(__FILE__, 'Anycover_activate');
add_action('admin_init', 'Anycover_Activation_redirect');

/**
 * Plugin activation callback. Registers option to redirect on next admin load.
 * 
 * @return void
 */
function Anycover_activate()
{
    add_option('Anycover_Activation_redirect', wp_get_current_user()->ID);
}

/** 
 * Get option value
 *
 * @return void
 */
function Anycover_Activation_redirect()
{
    global $CONFIG;
    $userId  = wp_get_current_user()->ID;
    if ((intval(get_option('Anycover_Activation_redirect', false)) == $userId) && is_admin() && is_user_logged_in() && current_user_can('activate_plugins')) {
        delete_option('Anycover_Activation_redirect');
        add_option('anycover_deactivation_redirect', wp_get_current_user()->ID);
        $store = get_site_url();
        $endpoint = '/wc-auth/v1/authorize';
        $params = [
        'app_name' => 'Anycover',
        'scope' => 'read_write',
        'user_id' => $store,
        'return_url' => $store . '/wp-admin',
        'callback_url' => $CONFIG['API_URL'] . '/v2/auth/woocommerce'
        ];
        $query_string = http_build_query($params);
        $redirect_url = $store . $endpoint . '?' . $query_string;
        wp_safe_redirect($redirect_url);
        exit;
    }
}


register_deactivation_hook(__FILE__, 'Anycover_deactivate');

/**
 * Registers the deactivation hook
 * 
 * @return void
 */
function Anycover_deactivate()
{
    global $wpdb, $CONFIG;
    $csKey = $wpdb->get_row(
        "SELECT truncated_key 
		FROM {$wpdb->prefix}woocommerce_api_keys 
		where description LIKE '%Anycover%'"
    );
    $secret = $csKey->truncated_key;
    $url = $CONFIG['API_URL'] . '/woocommerce/uninstall?' . http_build_query(
        array(
        'store' => get_site_url(),
        'secret' => $secret,
        )
    );
    Requests::delete($url, array('Content-Type' => 'application/json'));
    $wpdb->get_row(
        "DELETE FROM {$wpdb->prefix}woocommerce_api_keys 
		where description LIKE '%Anycover%'"
    );
}



add_action('wp_head', 'Widget_loading');
/**
 * Loading Widget script on product & cart pages for showing anycover widget
 * 
 * @return void
 */
function Widget_loading()
{
    global $CONFIG;
    if (is_product()) {
        global $post;
        $product =  wc_get_product($post->ID);
        $shop = get_site_url();
        $variants = null;
        if ($product->is_type('variable')) {
            $variants = $product->get_available_variations();
        }
        ?>
        <script>
            let storename = '<?php _e($shop); ?>'
            storename = new URL(storename);
            storename = storename.href.replace(`${storename.protocol}//`, '')
                .replace(/\//g, '.')
                .replace(/[.]$/, '');
            var anycoverWoocommerce = {
                variants: <?php _e(json_encode($variants)); ?>,
                product: <?php _e($product); ?>,
                shop: storename,
            }
        </script>
        <?php
        wp_enqueue_script("anycoverWidgetJS", $CONFIG['WIDGET_URL']);
    }
    if (is_cart()) {
        $cart = WC()->cart->get_cart();
        $shop = get_site_url();
        ?>
        <script>
            let storename = '<?php _e($shop) ?>'
            storename = new URL(storename);
            storename = storename.href.replace(`${storename.protocol}//`, '')
                .replace(/\//g, '.')
                .replace(/[.]$/, '');
            var anycoverWoocommerce = {
                cart: <?php _e(json_encode($cart)) ?>,
                shop: storename
            }
        </script>
        <?php
        wp_enqueue_script("anycoverWidgetJS", $CONFIG['WIDGET_URL']);
    }
}


add_action('wp_dashboard_setup', 'Anycover_Custom_Dashboard_widget');

/**
 * Creating a dashboard widget for redirecting to Anycover Dashboard
 *
 * @return void
 */
function Anycover_Custom_Dashboard_widget()
{
    wp_add_dashboard_widget(
        'Anycover_custom_dashboard',
        'Anycover',
        'Anycover_Dashboard_help'
    );
}

/**
 * Creating a dashboard widget for redirecting to Anycover Dashboard
 * 
 * @return void
 */
function Anycover_Dashboard_help()
{
    global $wpdb, $CONFIG;
    $csKey = $wpdb->get_row(
        "SELECT truncated_key 
		FROM {$wpdb->prefix}woocommerce_api_keys 
		where description LIKE '%Anycover%'"
    );
    $url = $CONFIG['UI_URL'] . '/auth/woocommerce?';
    $url = $url . 'shopname=' . get_site_url() . '&';
    $url = $url . 'merchant=woocommerce' . '&';
    $url = $url . 'secretKey=' . $csKey->truncated_key;
    echo '<p><a href=' . $url . '>Anycover Merchant Dashboard</a></p>';
}
